@@ -14,26 +14,33 @@
 from __future__ import annotations
 
 from abc import ABC, abstractmethod
-from typing import Union, TYPE_CHECKING, Literal, List
+from typing import TYPE_CHECKING, Any, Dict, List, Union
+
+from ..emailverification.interfaces import \
+    RecipeInterface as EmailVerificationRecipeInterface
+
+from typing_extensions import Literal
 
 from .provider import Provider
 
 if TYPE_CHECKING:
     from supertokens_python.framework import BaseRequest, BaseResponse
-    from .utils import ThirdPartyConfig
-    from .types import User, UsersResponse
+    from supertokens_python.recipe.session import SessionContainer
     from supertokens_python.supertokens import AppInfo
 
+    from .types import User
+    from .utils import ThirdPartyConfig
+
 
 class SignInUpResult(ABC):
     def __init__(self, status: Literal['OK', 'FIELD_ERROR'], user: Union[User, None] = None,
                  created_new_user: Union[bool, None] = None, error: Union[str, None] = None):
-        self.status = status
-        self.is_ok = False
-        self.is_field_error = False
-        self.user = user
-        self.created_new_user = created_new_user
-        self.error = error
+        self.status: Literal['OK', 'FIELD_ERROR'] = status
+        self.is_ok: bool = False
+        self.is_field_error: bool = False
+        self.user: Union[User, None] = user
+        self.created_new_user: Union[bool, None] = created_new_user
+        self.error: Union[str, None] = error
 
 
 class SignInUpOkResult(SignInUpResult):
@@ -53,64 +60,55 @@ class RecipeInterface(ABC):
         pass
 
     @abstractmethod
-    async def get_user_by_id(self, user_id: str) -> Union[User, None]:
+    async def get_user_by_id(self, user_id: str, user_context: Dict[str, Any]) -> Union[User, None]:
         pass
 
     @abstractmethod
-    async def get_users_by_email(self, email: str) -> List[User]:
+    async def get_users_by_email(self, email: str, user_context: Dict[str, Any]) -> List[User]:
         pass
 
     @abstractmethod
-    async def get_user_by_thirdparty_info(self, third_party_id: str, third_party_user_id: str) -> Union[User, None]:
+    async def get_user_by_thirdparty_info(self, third_party_id: str, third_party_user_id: str,
+                                          user_context: Dict[str, Any]) -> Union[User, None]:
         pass
 
     @abstractmethod
     async def sign_in_up(self, third_party_id: str, third_party_user_id: str, email: str,
-                         email_verified: bool) -> SignInUpResult:
-        pass
-
-    @abstractmethod
-    async def get_users_oldest_first(self, limit: int = None, next_pagination: str = None) -> UsersResponse:
-        pass
-
-    @abstractmethod
-    async def get_users_newest_first(self, limit: int = None, next_pagination: str = None) -> UsersResponse:
-        pass
-
-    @abstractmethod
-    async def get_user_count(self) -> int:
+                         email_verified: bool, user_context: Dict[str, Any]) -> SignInUpResult:
         pass
 
 
 class APIOptions:
-    def __init__(self, request: BaseRequest, response: Union[BaseResponse, None], recipe_id: str,
-                 config: ThirdPartyConfig, recipe_implementation: RecipeInterface, providers: List[Provider],
-                 app_info: AppInfo):
-        self.request = request
-        self.response = response
-        self.recipe_id = recipe_id
-        self.config = config
-        self.providers = providers
-        self.recipe_implementation = recipe_implementation
-        self.app_info = app_info
+    def __init__(self, request: BaseRequest, response: BaseResponse, recipe_id: str,
+                 config: ThirdPartyConfig, recipe_implementation: RecipeInterface, providers: List[Provider], app_info: AppInfo, email_verification_recipe_implementation: EmailVerificationRecipeInterface):
+        self.request: BaseRequest = request
+        self.response: BaseResponse = response
+        self.recipe_id: str = recipe_id
+        self.config: ThirdPartyConfig = config
+        self.providers: List[Provider] = providers
+        self.recipe_implementation: RecipeInterface = recipe_implementation
+        self.app_info: AppInfo = app_info
+        self.email_verification_recipe_implementation: EmailVerificationRecipeInterface = email_verification_recipe_implementation
 
 
 class SignInUpPostResponse(ABC):
     def __init__(self, status: Literal['OK', 'NO_EMAIL_GIVEN_BY_PROVIDER', 'FIELD_ERROR'], user: Union[User, None] = None,
-                 created_new_user: Union[bool, None] = None, auth_code_response: any = None,
-                 error: Union[str, None] = None):
+                 created_new_user: Union[bool, None] = None, auth_code_response: Union[Dict[str, Any], None] = None,
+                 error: Union[str, None] = None,
+                 session: Union[SessionContainer, None] = None):
         self.type = 'thirdparty'
-        self.status = status
-        self.is_ok = False
-        self.is_no_email_given_by_provider = False
-        self.is_field_error = False
-        self.user = user
-        self.created_new_user = created_new_user
-        self.error = error
-        self.auth_code_response = auth_code_response
+        self.status: Literal['OK', 'NO_EMAIL_GIVEN_BY_PROVIDER', 'FIELD_ERROR'] = status
+        self.is_ok: bool = False
+        self.is_no_email_given_by_provider: bool = False
+        self.is_field_error: bool = False
+        self.user: Union[User, None] = user
+        self.created_new_user: Union[bool, None] = created_new_user
+        self.error: Union[str, None] = error
+        self.auth_code_response: Union[Dict[str, Any], None] = auth_code_response
+        self.session: Union[SessionContainer, None] = session
 
     @abstractmethod
-    def to_json(self):
+    def to_json(self) -> Dict[str, Any]:
         pass
 
 
@@ -145,11 +143,14 @@ class PasswordResetResponse(ABC):
 
 class SignInUpPostOkResponse(SignInUpPostResponse):
     def __init__(self, user: User, created_new_user: bool,
-                 auth_code_response: any):
-        super().__init__('OK', user, created_new_user, auth_code_response)
+                 auth_code_response: Dict[str, Any],
+                 session: SessionContainer):
+        super().__init__('OK', user, created_new_user, auth_code_response, session=session)
         self.is_ok = True
 
-    def to_json(self):
+    def to_json(self) -> Dict[str, Any]:
+        if self.user is None:
+            raise Exception("Should never come here")
         return {
             'status': self.status,
             'user': {
@@ -211,12 +212,16 @@ class APIInterface:
         self.disable_authorisation_url_get = False
         self.disable_apple_redirect_handler_post = False
 
-    async def authorisation_url_get(self, provider: Provider, api_options: APIOptions) -> AuthorisationUrlGetResponse:
+    @abstractmethod
+    async def authorisation_url_get(self, provider: Provider,
+                                    api_options: APIOptions, user_context: Dict[str, Any]) -> AuthorisationUrlGetResponse:
         pass
 
-    async def sign_in_up_post(self, provider: Provider, code: str, redirect_uri: str, client_id: Union[str, None],
-                              auth_code_response: Union[str, None], api_options: APIOptions) -> SignInUpPostResponse:
+    @abstractmethod
+    async def sign_in_up_post(self, provider: Provider, code: str, redirect_uri: str, client_id: Union[str, None], auth_code_response: Union[Dict[str, Any], None], api_options: APIOptions,
+                              user_context: Dict[str, Any]) -> SignInUpPostResponse:
         pass
 
-    async def apple_redirect_handler_post(self, code: str, state: str, api_options: APIOptions):
+    @abstractmethod
+    async def apple_redirect_handler_post(self, code: str, state: str, api_options: APIOptions, user_context: Dict[str, Any]):
         pass
