@@ -14,38 +14,52 @@
 from __future__ import annotations
 
 from os import environ
-from typing import List, TYPE_CHECKING, Union
-
-from supertokens_python.recipe.thirdparty.provider import Provider
+from typing import TYPE_CHECKING, Any, Dict, List, Union
 
+from supertokens_python.framework.response import BaseResponse
 from supertokens_python.normalised_url_path import NormalisedURLPath
-from supertokens_python.recipe_module import RecipeModule, APIHandled
-from .api.emailpassword_api_impementation import get_interface_impl as get_email_password_interface_impl
+from supertokens_python.querier import Querier
+from supertokens_python.recipe.thirdparty.provider import Provider
+from supertokens_python.recipe_module import APIHandled, RecipeModule
+
+from ..emailpassword.utils import (InputResetPasswordUsingTokenFeature,
+                                   InputSignUpFeature)
+from .api.emailpassword_api_impementation import \
+    get_interface_impl as get_email_password_interface_impl
 from .api.implementation import APIImplementation
-from .api.thirdparty_api_implementation import get_interface_impl as get_third_party_interface_impl
+from .api.thirdparty_api_implementation import \
+    get_interface_impl as get_third_party_interface_impl
 from .recipeimplementation.email_password_recipe_implementation import \
     RecipeImplementation as EmailPasswordRecipeImplementation
 from .recipeimplementation.implementation import RecipeImplementation
 from .recipeimplementation.third_party_recipe_implementation import \
     RecipeImplementation as ThirdPartyRecipeImplementation
-from supertokens_python.framework.response import BaseResponse
-from supertokens_python.querier import Querier
-from ..emailpassword.utils import InputSignUpFeature, InputResetPasswordUsingTokenFeature
-from ..emailverification.utils import InputEmailVerificationConfig
+from .utils import InputEmailVerificationConfig
 
 if TYPE_CHECKING:
     from supertokens_python.framework.request import BaseRequest
     from supertokens_python.supertokens import AppInfo
+
 from supertokens_python.exceptions import SuperTokensError
-from .exceptions import SupertokensThirdPartyEmailPasswordError
-from supertokens_python.recipe.emailverification import EmailVerificationRecipe
 from supertokens_python.recipe.emailpassword import EmailPasswordRecipe
+from supertokens_python.recipe.emailpassword.utils import \
+    InputOverrideConfig as EPOverrideConfig
+from supertokens_python.recipe.emailverification import EmailVerificationRecipe
 from supertokens_python.recipe.thirdparty import ThirdPartyRecipe
-from .utils import (
-    validate_and_normalise_user_input, InputOverrideConfig
-)
-from supertokens_python.recipe.thirdparty.utils import InputOverrideConfig as TPOverrideConfig, SignInAndUpFeature
-from supertokens_python.recipe.emailpassword.utils import InputOverrideConfig as EPOverrideConfig
+from supertokens_python.recipe.thirdparty.utils import \
+    InputOverrideConfig as TPOverrideConfig
+from supertokens_python.recipe.thirdparty.utils import SignInAndUpFeature
+
+from ..emailpassword.interfaces import \
+    APIInterface as EmailPasswordAPIInterface
+from ..emailpassword.interfaces import \
+    RecipeInterface as EmailPasswordRecipeInterface
+from ..thirdparty.interfaces import APIInterface as ThirdPartyAPIInterface
+from ..thirdparty.interfaces import \
+    RecipeInterface as ThirdPartyRecipeInterface
+from .exceptions import SupertokensThirdPartyEmailPasswordError
+from .interfaces import APIInterface, RecipeInterface
+from .utils import InputOverrideConfig, validate_and_normalise_user_input
 
 
 class ThirdPartyEmailPasswordRecipe(RecipeModule):
@@ -72,10 +86,10 @@ class ThirdPartyEmailPasswordRecipe(RecipeModule):
 
         recipe_implementation = RecipeImplementation(Querier.get_instance(EmailPasswordRecipe.recipe_id),
                                                      Querier.get_instance(ThirdPartyRecipe.recipe_id))
-        self.recipe_implementation = recipe_implementation if self.config.override.functions is None else \
+        self.recipe_implementation: RecipeInterface = recipe_implementation if self.config.override.functions is None else \
             self.config.override.functions(recipe_implementation)
         api_implementation = APIImplementation()
-        self.api_implementation = api_implementation if self.config.override.apis is None else \
+        self.api_implementation: APIInterface = api_implementation if self.config.override.apis is None else \
             self.config.override.apis(api_implementation)
 
         if email_verification_recipe is not None:
@@ -84,20 +98,18 @@ class ThirdPartyEmailPasswordRecipe(RecipeModule):
             self.email_verification_recipe = EmailVerificationRecipe(recipe_id, app_info,
                                                                      self.config.email_verification_feature)
 
-        def func_override_email_password(_):
+        def func_override_email_password(_: EmailPasswordRecipeInterface) -> EmailPasswordRecipeInterface:
             return EmailPasswordRecipeImplementation(
                 self.recipe_implementation)
 
-        def apis_override_email_password(_):
+        def apis_override_email_password(_: EmailPasswordAPIInterface) -> EmailPasswordAPIInterface:
             return get_email_password_interface_impl(self.api_implementation)
 
-        form_fields = None if self.config.sign_up_feature is None else self.config.sign_up_feature.form_fields
-
         if email_password_recipe is not None:
             self.email_password_recipe = email_password_recipe
         else:
             self.email_password_recipe = EmailPasswordRecipe(recipe_id, app_info,
-                                                             InputSignUpFeature(form_fields),
+                                                             self.config.sign_up_feature,
                                                              self.config.reset_password_using_token_feature,
                                                              None,
                                                              EPOverrideConfig(
@@ -106,14 +118,14 @@ class ThirdPartyEmailPasswordRecipe(RecipeModule):
                                                              ),
                                                              self.email_verification_recipe)
 
-        def func_override_third_party(_):
+        def func_override_third_party(_: ThirdPartyRecipeInterface) -> ThirdPartyRecipeInterface:
             return ThirdPartyRecipeImplementation(self.recipe_implementation)
 
-        def apis_override_third_party(_):
+        def apis_override_third_party(_: ThirdPartyAPIInterface) -> ThirdPartyAPIInterface:
             return get_third_party_interface_impl(self.api_implementation)
 
         if third_party_recipe is not None:
-            self.third_party_recipe = third_party_recipe
+            self.third_party_recipe: Union[ThirdPartyRecipe, None] = third_party_recipe
         else:
             self.third_party_recipe: Union[ThirdPartyRecipe, None] = None
             if len(self.config.providers) != 0:
@@ -129,7 +141,8 @@ class ThirdPartyEmailPasswordRecipe(RecipeModule):
                     self.email_verification_recipe
                 )
 
-    def is_error_from_this_recipe_based_on_instance(self, err):
+    def is_error_from_this_recipe_based_on_instance(
+            self, err: Exception) -> bool:
         return isinstance(err, SuperTokensError) and (
             isinstance(err, SupertokensThirdPartyEmailPasswordError)
             or
@@ -159,24 +172,22 @@ class ThirdPartyEmailPasswordRecipe(RecipeModule):
         if self.email_password_recipe.return_api_id_if_can_handle_request(
                 path, method) is not None:
             return await self.email_password_recipe.handle_api_request(request_id, request, path, method, response)
-        elif self.third_party_recipe is not None and self.third_party_recipe.return_api_id_if_can_handle_request(path,
-                                                                                                                 method) is not None:
+        if self.third_party_recipe is not None and self.third_party_recipe.return_api_id_if_can_handle_request(path,
+                                                                                                               method) is not None:
             return await self.third_party_recipe.handle_api_request(request_id, request, path, method, response)
-        else:
-            return await self.email_verification_recipe.handle_api_request(request_id, request, path, method, response)
+        return await self.email_verification_recipe.handle_api_request(request_id, request, path, method, response)
 
-    async def handle_error(self, request: BaseRequest, error: SuperTokensError, response: BaseResponse):
+    async def handle_error(self, request: BaseRequest, err: SuperTokensError, response: BaseResponse) -> BaseResponse:
         if self.email_password_recipe.is_error_from_this_recipe_based_on_instance(
-                error):
-            return self.email_password_recipe.handle_error(
-                request, error, response)
+                err):
+            return await self.email_password_recipe.handle_error(
+                request, err, response)
         if self.third_party_recipe is not None and self.third_party_recipe.is_error_from_this_recipe_based_on_instance(
-                error):
-            return self.third_party_recipe.handle_error(
-                request, error, response)
-        else:
-            return self.email_verification_recipe.handle_error(
-                request, error, response)
+                err):
+            return await self.third_party_recipe.handle_error(
+                request, err, response)
+        return await self.email_verification_recipe.handle_error(
+            request, err, response)
 
     def get_all_cors_headers(self) -> List[str]:
         cors_headers = self.email_password_recipe.get_all_cors_headers(
@@ -200,9 +211,7 @@ class ThirdPartyEmailPasswordRecipe(RecipeModule):
                     override,
                     providers)
                 return ThirdPartyEmailPasswordRecipe.__instance
-            else:
-                raise Exception(None, 'ThirdPartyEmailPassword recipe has already been initialised. Please '
-                                      'check your code for bugs.')
+            raise Exception(None, 'ThirdPartyEmailPassword recipe has already been initialised. Please check your code for bugs.')
 
         return func
 
@@ -222,8 +231,8 @@ class ThirdPartyEmailPasswordRecipe(RecipeModule):
                 None, 'calling testing function in non testing env')
         ThirdPartyEmailPasswordRecipe.__instance = None
 
-    async def get_email_for_user_id(self, user_id: str) -> str:
-        user_info = await self.recipe_implementation.get_user_by_id(user_id)
+    async def get_email_for_user_id(self, user_id: str, user_context: Dict[str, Any]) -> str:
+        user_info = await self.recipe_implementation.get_user_by_id(user_id, user_context)
         if user_info is None:
             raise Exception('Unknown User ID provided')
         return user_info.email
