@@ -33,7 +33,7 @@ from .recipe.session.cookie_and_header import (
     attach_id_refresh_token_to_cookie_and_header,
     attach_refresh_token_to_cookie, clear_cookies, set_front_token_in_headers)
 from .types import ThirdPartyInfo, User, UsersResponse
-from .utils import (compare_version, get_rid_from_request,
+from .utils import (get_max_version, get_rid_from_request,
                     normalise_http_method, send_non_200_response)
 
 if TYPE_CHECKING:
@@ -42,7 +42,6 @@ if TYPE_CHECKING:
     from supertokens_python.framework.response import BaseResponse
     from supertokens_python.recipe.session import SessionContainer
 
-import asyncio
 import json
 from os import environ
 
@@ -195,12 +194,7 @@ class Supertokens:
                 environ['SUPERTOKENS_ENV'] != 'testing')
 
         if telemetry:
-            if self.app_info.framework.lower(
-            ) == 'flask' or self.app_info.framework.lower() == 'django':
-                loop = asyncio.get_event_loop()
-                loop.run_until_complete(self.send_telemetry())
-            else:
-                asyncio.create_task(self.send_telemetry())
+            _ = self.send_telemetry()
 
     async def send_telemetry(self):
         try:
@@ -280,7 +274,7 @@ class Supertokens:
 
         cdi_version = await querier.get_api_version()
 
-        if compare_version(cdi_version, "2.10") == cdi_version:
+        if get_max_version(cdi_version, "2.10") == cdi_version:
             await querier.send_post_request(NormalisedURLPath(USER_DELETE), {
                 "userId": user_id
             })
