@@ -15,22 +15,19 @@ under the License.
 """
 
 from pytest import mark
-
-from supertokens_python import init, SupertokensConfig, InputAppInfo
+from supertokens_python import InputAppInfo, SupertokensConfig, init
 from supertokens_python.recipe import jwt
 from supertokens_python.recipe.jwt import JWTRecipe
-from tests.utils import (
-    reset, setup_st, clean_st, start_st
-)
+from tests.utils import clean_st, reset, setup_st, start_st
 
 
-def setup_function(f):
+def setup_function(_):
     reset()
     clean_st()
     setup_st()
 
 
-def teardown_function(f):
+def teardown_function(_):
     reset()
     clean_st()
 
